"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _MessageType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MessageTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MessageType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ACK: _MessageType.ValueType  # 0
    COLLECT_INTERVAL: _MessageType.ValueType  # 160
    """in ms"""
    BEEP_ON: _MessageType.ValueType  # 161
    """duration ms"""
    BEEP_OFF: _MessageType.ValueType  # 162
    """cancel prematurely"""
    SHUTDOWN: _MessageType.ValueType  # 163
    POWER_ON: _MessageType.ValueType  # 164
    SCD41_TEMP: _MessageType.ValueType  # 176
    SCD41_HUMIDITY: _MessageType.ValueType  # 177
    SCD41_CO2: _MessageType.ValueType  # 178
    AHT20_TEMP: _MessageType.ValueType  # 179
    AHT20_HUMIDITY: _MessageType.ValueType  # 180
    TVOC_INDEX: _MessageType.ValueType  # 181

class MessageType(_MessageType, metaclass=_MessageTypeEnumTypeWrapper):
    """encapsulate up to 1k of NMEA string data"""

ACK: MessageType.ValueType  # 0
COLLECT_INTERVAL: MessageType.ValueType  # 160
"""in ms"""
BEEP_ON: MessageType.ValueType  # 161
"""duration ms"""
BEEP_OFF: MessageType.ValueType  # 162
"""cancel prematurely"""
SHUTDOWN: MessageType.ValueType  # 163
POWER_ON: MessageType.ValueType  # 164
SCD41_TEMP: MessageType.ValueType  # 176
SCD41_HUMIDITY: MessageType.ValueType  # 177
SCD41_CO2: MessageType.ValueType  # 178
AHT20_TEMP: MessageType.ValueType  # 179
AHT20_HUMIDITY: MessageType.ValueType  # 180
TVOC_INDEX: MessageType.ValueType  # 181
global___MessageType = MessageType

@typing.final
class SensorData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    FLOAT_VALUE_FIELD_NUMBER: builtins.int
    UINT32_VALUE_FIELD_NUMBER: builtins.int
    type: global___MessageType.ValueType
    """The message type"""
    float_value: builtins.float
    uint32_value: builtins.int
    def __init__(
        self,
        *,
        type: global___MessageType.ValueType = ...,
        float_value: builtins.float = ...,
        uint32_value: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "float_value", b"float_value", "uint32_value", b"uint32_value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "float_value", b"float_value", "type", b"type", "uint32_value", b"uint32_value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["data", b"data"]) -> typing.Literal["float_value", "uint32_value"] | None: ...

global___SensorData = SensorData

@typing.final
class InterdeviceMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NMEA_FIELD_NUMBER: builtins.int
    SENSOR_FIELD_NUMBER: builtins.int
    nmea: builtins.str
    @property
    def sensor(self) -> global___SensorData: ...
    def __init__(
        self,
        *,
        nmea: builtins.str = ...,
        sensor: global___SensorData | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "nmea", b"nmea", "sensor", b"sensor"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "nmea", b"nmea", "sensor", b"sensor"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["data", b"data"]) -> typing.Literal["nmea", "sensor"] | None: ...

global___InterdeviceMessage = InterdeviceMessage
